==> aws-java-sdk-support-1.10.46-sources.jar: com/amazonaws/services/support/model/transform/AttachmentDetailsJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.support.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.support.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * AttachmentDetailsMarshaller
 */
public class AttachmentDetailsJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a JSONWriter
     */
    public void marshall(AttachmentDetails attachmentDetails,
            JSONWriter jsonWriter) {
        if (attachmentDetails == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonWriter.object();

            if (attachmentDetails.getAttachmentId() != null) {
                jsonWriter.key("attachmentId").value(
                        attachmentDetails.getAttachmentId());
            }

            if (attachmentDetails.getFileName() != null) {
                jsonWriter.key("fileName").value(
                        attachmentDetails.getFileName());
            }

            jsonWriter.endObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static AttachmentDetailsJsonMarshaller instance;

    public static AttachmentDetailsJsonMarshaller getInstance() {
        if (instance == null)
            instance = new AttachmentDetailsJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-support-1.10.64-sources.jar: com/amazonaws/services/support/model/transform/AttachmentDetailsJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.support.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.support.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * AttachmentDetailsMarshaller
 */
public class AttachmentDetailsJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(AttachmentDetails attachmentDetails,
            SdkJsonGenerator jsonGenerator) {
        if (attachmentDetails == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (attachmentDetails.getAttachmentId() != null) {
                jsonGenerator.writeFieldName("attachmentId").writeValue(
                        attachmentDetails.getAttachmentId());
            }
            if (attachmentDetails.getFileName() != null) {
                jsonGenerator.writeFieldName("fileName").writeValue(
                        attachmentDetails.getFileName());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static AttachmentDetailsJsonMarshaller instance;

    public static AttachmentDetailsJsonMarshaller getInstance() {
        if (instance == null)
            instance = new AttachmentDetailsJsonMarshaller();
        return instance;
    }

}
